@@ -15,11 +15,11 @@ from gi.repository import Graphene
 from gi.repository import Gsk
 from gi.repository import Gtk
 
+from komikku.models import Settings
+
 logger = logging.getLogger('komikku')
 
 PRELOAD = 5  # in widget height unit
-SCROLL_CLICK_PERCENTAGE = 2 / 3
-SCROLL_DRAG_FACTOR = 2
 
 
 class KInfiniteCanvas(Gtk.Widget, Gtk.Scrollable):
@@ -35,6 +35,7 @@ class KInfiniteCanvas(Gtk.Widget, Gtk.Scrollable):
         super().__init__()
 
         self.pager = pager
+        self.settings = Settings.get_default()
 
         self.__hadj = None
         self.__vadj = None
@@ -300,10 +301,10 @@ class KInfiniteCanvas(Gtk.Widget, Gtk.Scrollable):
 
         if x < self.canvas_width / 3:
             # First third: scroll up
-            self.scroll_by_increment(-self.vadjustment.props.page_size * SCROLL_CLICK_PERCENTAGE)
+            self.scroll_by_increment(-self.vadjustment.props.page_size * self.settings.scroll_click_percentage)
         elif x > 2 * self.canvas_width / 3:
             # Last third: scroll down
-            self.scroll_by_increment(self.vadjustment.props.page_size * SCROLL_CLICK_PERCENTAGE)
+            self.scroll_by_increment(self.vadjustment.props.page_size * self.settings.scroll_click_percentage)
         else:
             # Second third: controls zone
             self.emit('controls-zone-clicked')
@@ -325,7 +326,7 @@ class KInfiniteCanvas(Gtk.Widget, Gtk.Scrollable):
             return
 
         self.scroll_direction = Gtk.DirectionType.UP if offset_y > 0 else Gtk.DirectionType.DOWN
-        self.vadjustment.props.value -= (offset_y - self.scroll_drag_offset) * SCROLL_DRAG_FACTOR
+        self.vadjustment.props.value -= (offset_y - self.scroll_drag_offset) * self.settings.scroll_drag_factor
         self.scroll_drag_offset = offset_y
 
         self.gesture_drag.set_state(Gtk.EventSequenceState.CLAIMED)
@@ -350,12 +351,12 @@ class KInfiniteCanvas(Gtk.Widget, Gtk.Scrollable):
 
         elif keyval == Gdk.KEY_Page_Down:
             self.emit('keyboard-navigation')
-            self.scroll_by_increment(self.vadjustment.props.page_size * SCROLL_CLICK_PERCENTAGE)
+            self.scroll_by_increment(self.vadjustment.props.page_size * self.settings.scroll_click_percentage)
             return Gdk.EVENT_STOP
 
         elif keyval == Gdk.KEY_Page_Up:
             self.emit('keyboard-navigation')
-            self.scroll_by_increment(-self.vadjustment.props.page_size * SCROLL_CLICK_PERCENTAGE)
+            self.scroll_by_increment(-self.vadjustment.props.page_size * self.settings.scroll_click_percentage)
             return Gdk.EVENT_STOP
 
         return Gdk.EVENT_PROPAGATE
