@@ -15,8 +15,8 @@ class Animesama(Server):
     name = 'Anime-Sama'
     lang = 'fr'
 
-    base_url = 'https://anime-sama.org'
-    logo_url = 'https://cdn.statically.io/gh/Anime-Sama/IMG/img/autres/logo_icon.png'
+    base_url = 'https://anime-sama.tv'
+    logo_url = base_url + '/img/favicon.ico?v=4'
     search_url = base_url + '/catalogue/'
     manga_url = base_url + '/catalogue/{0}/'
     chapter_url = base_url + '/catalogue/{0}/scan/vf/'
@@ -59,10 +59,10 @@ class Animesama(Server):
         data['name'] = soup.select_one('#titreOeuvre').text.strip()
         data['cover'] = soup.select_one('#coverOeuvre').get('src')
 
-        if element := soup.select_one('p.text-sm.text-gray-400.mt-2'):
+        if element := soup.select_one('div h2:-soup-contains("Synopsis") ~ p'):
             data['synopsis'] = element.text.strip()
 
-        if element := soup.select_one('a.text-sm.text-gray-300.mt-2'):
+        if element := soup.select_one('div h2:-soup-contains("Genres") ~ a'):
             genres = element.text
             if ',' in genres:
                 genres = genres.split(',')
@@ -186,14 +186,14 @@ class Animesama(Server):
             a_element = element.a
             img_element = a_element.img
 
-            if last_element := element.select_one('button.bg-slate-700'):
+            if last_element := element.select_one('.card-info .info-text'):
                 last_chapter = last_element.text.strip()
             else:
                 last_chapter = None
 
             results.append(dict(
                 slug=a_element.get('href').split('/')[-4],
-                name=a_element.select_one('h1').text.strip(),
+                name=a_element.select_one('.card-title').text.strip(),
                 cover=img_element.get('src'),
                 last_chapter=last_chapter,
             ))
@@ -231,7 +231,7 @@ class Animesama(Server):
 
             results.append(dict(
                 slug=slug,
-                name=a_element.select_one('h1').text.strip(),
+                name=a_element.select_one('.card-title').text.strip(),
                 cover=img_element.get('src'),
             ))
 
