@@ -4,7 +4,6 @@
 
 import base64
 from gettext import gettext as _
-import json
 import logging
 
 from bs4 import BeautifulSoup
@@ -13,39 +12,12 @@ import requests
 from komikku.consts import USER_AGENT
 from komikku.servers import Server
 from komikku.servers.utils import convert_date_string
+from komikku.servers.utils import parse_nextjs_hydration
 from komikku.utils import get_buffer_mime_type
 
 logger = logging.getLogger(__name__)
 
 
-def extract_info_from_script(soup, keyword):
-    info = None
-
-    for script_element in soup.select('script'):
-        script = script_element.string
-        if not script or not script.startswith('self.__next_f.push([1,') or keyword not in script:
-            continue
-
-        line = script.strip().replace('self.__next_f.push([1,', '')
-
-        start = 0
-        for c in line:
-            if c in ('{', '['):
-                break
-            start += 1
-
-        line = line[start:-3]
-
-        try:
-            info = json.loads(f'"{line}"')
-        except Exception as e:
-            logger.debug(f'ERROR: {line}')
-            logger.debug(e)
-        break
-
-    return info
-
-
 class Coloredcouncil(Server):
     id = 'coloredcouncil'
     name = 'Colored Manga'
@@ -112,8 +84,8 @@ class Coloredcouncil(Server):
 
         soup = BeautifulSoup(r.text, 'lxml')
 
-        if info := extract_info_from_script(soup, 'totalImage'):
-            info = json.loads(info)[3]['data']
+        if info := parse_nextjs_hydration(soup, 'totalImage'):
+            info = info[3]['data']
         else:
             logger.error('Failed to retrieve manga data')
             return None
@@ -293,9 +265,9 @@ class Coloredcouncil(Server):
                 return None
 
             soup = BeautifulSoup(r.text, 'lxml')
-            if info := extract_info_from_script(soup, 'totalImage'):
+            if info := parse_nextjs_hydration(soup, 'totalImage'):
                 try:
-                    info = json.loads(info)[3]['children'][3]['data']
+                    info = info[3]['children'][3]['data']
                 except Exception:
                     logger.error('Failed to retrieve manga list')
                     return None
