@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from komikku.servers.multi.manga_stream import MangaStream
@@ -10,11 +10,10 @@ class Komiklovers(MangaStream):
     name = 'KomikLovers'
     lang = 'id'
 
-    has_cf = True
-
     series_name = 'komik'
 
     base_url = 'https://komiklovers.com'
+    logo_url = 'https://i1.wp.com/komiklovers.com/wp-content/uploads/2024/05/cropped-SAVE_20240527_203449-32x32.jpg'
 
     authors_selector = '.infotable tr:-soup-contains("Artist") td:last-child, .infotable tr:-soup-contains("Author") td:last-child'
     genres_selector = '.seriestugenre a'
