@@ -2,11 +2,15 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
-from urllib.parse import unquote
+import logging
+import re
 
 from bs4 import BeautifulSoup
 
 from komikku.servers.multi.madara import Madara2
+from komikku.utils import get_buffer_mime_type
+
+logger = logging.getLogger(__name__)
 
 
 class Mangacrab(Madara2):
@@ -42,15 +46,28 @@ class Mangacrab(Madara2):
 
         soup = BeautifulSoup(r.text, 'lxml')
 
+        img_key = None
+        for script_element in soup.find_all('script'):
+            script = script_element.string
+            if script and 'X-Img-Key' in script:
+                re_key = r"'X-Img-Key': '(.*)'"
+                if matches := re.search(re_key, script):
+                    img_key = matches.group(1)
+                    break
+
+        if img_key is None:
+            logger.info('Failed to retrieve X-Img-Key header value')
+            return None
+
         data = dict(
             pages=[],
         )
         index = 1
-        for img_element in soup.select('.reading-content img.wp-manga-chapter-img'):
+        for img_element in soup.select('.page-break img.wp-manga-chapter-img'):
             image = None
             for attr, value in img_element.attrs.items():
-                if isinstance(value, str) and 'validate' in value:
-                    image = unquote(value.split('?file=')[1]).split('&sig=')[0]
+                if isinstance(value, str) and 'encript.php' in value:
+                    image = value
                     break
             if image is None:
                 continue
@@ -59,11 +76,37 @@ class Mangacrab(Madara2):
                 slug=None,
                 image=f'{self.base_url}/{image}',
                 index=index,
+                key=img_key,
             ))
             index += 1
 
         return data
 
+    def get_manga_chapter_page_image(self, manga_slug, manga_name, chapter_slug, page):
+        """
+        Returns chapter page scan (image) content
+        """
+        r = self.session_get(
+            page['image'],
+            headers={
+                'Accept': 'image/*',
+                'Referer': self.chapter_url.format(manga_slug, chapter_slug),
+                'X-Img-Key': page['key'],
+            }
+        )
+        if r.status_code != 200:
+            return None
+
+        mime_type = get_buffer_mime_type(r.content)
+        if not mime_type.startswith('image'):
+            return None
+
+        return dict(
+            buffer=r.content,
+            mime_type=mime_type,
+            name='{0:03d}.{1}'.format(page['index'], mime_type.split('/')[-1]),
+        )
+
     def search(self, term, nsfw, orderby=None):
         params = {
             'post_type': 'wp-manga',
