@@ -5,14 +5,15 @@
 # Hean CMS / Iken
 
 # Supported servers:
-# Aurora Scans [EN]
+# Aurora Scans [EN] (disabled)
 # EZmanga [EN]
 # Hijala Scans [EN]
+# Hive Toon [EN]
 # Mode Scanlator [pt_BR] (disabled)
 # Qi Scans [EN]
 # Reaper Scans [EN] (disabled)
 # Reaper Scans [pt_BR] (disabled)
-# Rezo Scans [EN]
+# Rezo Scans [EN] (disabled)
 
 
 import logging
@@ -136,9 +137,7 @@ class HeanCMS(Server):
 
         soup = BeautifulSoup(r.text, 'lxml')
 
-        if info := parse_nextjs_hydration(soup, 'API_Response'):
-            images = info[1][3]['API_Response']['chapter']['images']
-
+        if images := parse_nextjs_hydration(soup, 'images', key='images'):
             data = dict(
                 pages=[],
             )
