@@ -12,10 +12,10 @@ from bs4 import BeautifulSoup
 import requests
 from urllib.parse import urlsplit
 
-from komikku.servers import DOWNLOAD_MAX_DELAY
+from komikku.consts import DOWNLOAD_MAX_DELAY
+from komikku.consts import USER_AGENT
+from komikku.consts import USER_AGENT_MOBILE
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
-from komikku.servers import USER_AGENT_MOBILE
 from komikku.servers.utils import get_soup_element_inner_text
 from komikku.utils import get_buffer_mime_type
 from komikku.utils import get_response_elapsed
